==> 0.0.40.tar.gz: android/src/main/java/com/app/flutter/mtpl/flutter_test_selfiecapture/FlutterTestSelfiecapturePlugin.java <==
package com.app.flutter.mtpl.flutter_test_selfiecapture;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterTestSelfiecapturePlugin
 */
public class FlutterTestSelfiecapturePlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
    /**
     * Plugin registration.
     */

    Activity context;
    MethodChannel methodChannel;
    public static Result result;

    public FlutterTestSelfiecapturePlugin(Activity activity, MethodChannel methodChannel) {
        this.context = activity;
        this.methodChannel = methodChannel;
        this.methodChannel.setMethodCallHandler(this);
    }

    public FlutterTestSelfiecapturePlugin(Activity activity) {
        this.context = activity;
    }


    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_test_selfiecapture");
        //channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin());
        channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin(registrar.activity(), channel));

        final FlutterTestSelfiecapturePlugin plugin = new FlutterTestSelfiecapturePlugin(registrar.activity());

        registrar.addActivityResultListener(plugin);
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equalsIgnoreCase("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equalsIgnoreCase("detectLiveliness")) {
            this.result = result;
            //result.success(detectLiveliness(context));
            detectLiveliness(context);
        } else {
            result.notImplemented();
        }
    }

    private void detectLiveliness(Activity activity) {
        Intent intent = new Intent(activity, FaceTrackerActivity.class);
        activity.startActivityForResult(intent, 100);
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        if (resultCode != Activity.RESULT_CANCELED) {

            if (requestCode == 100) {
                if (result != null) {
                    String filePath = data.getStringExtra("filePath");
                    Log.e("filePath.plugin", filePath);
                    result.success(filePath);
                } else {
                    Log.e("RESULT", "NULL");
                }
            }
            return true;
        }
        return false;
    }
}

==> 0.0.50.tar.gz: android/src/main/java/com/app/flutter/mtpl/flutter_test_selfiecapture/FlutterTestSelfiecapturePlugin.java <==
package com.app.flutter.mtpl.flutter_test_selfiecapture;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterTestSelfiecapturePlugin
 */
public class FlutterTestSelfiecapturePlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
    /**
     * Plugin registration.
     */

    Activity context;
    MethodChannel methodChannel;
    public static Result result;

    public FlutterTestSelfiecapturePlugin(Activity activity, MethodChannel methodChannel) {
        this.context = activity;
        this.methodChannel = methodChannel;
        this.methodChannel.setMethodCallHandler(this);
    }

    public FlutterTestSelfiecapturePlugin(Activity activity) {
        this.context = activity;
    }


    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_test_selfiecapture");
        //channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin());
        channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin(registrar.activity(), channel));

        final FlutterTestSelfiecapturePlugin plugin = new FlutterTestSelfiecapturePlugin(registrar.activity());

        registrar.addActivityResultListener(plugin);
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equalsIgnoreCase("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equalsIgnoreCase("detectLiveliness")) {
            this.result = result;
            //result.success(detectLiveliness(context));
            String msgselfieCapture = call.argument("msgselfieCapture");
            String msgBlinkEye = call.argument("msgBlinkEye");
            //result.success(detectLiveliness(context));
            detectLiveliness(context,msgselfieCapture,msgBlinkEye);
        } else {
            result.notImplemented();
        }
    }

    private void detectLiveliness(Activity activity,String msgselfieCapture,String msgBlinkEye) {
        Intent intent = new Intent(activity, FaceTrackerActivity.class);
        intent.putExtra("msgselfieCapture",msgselfieCapture);
        intent.putExtra("msgBlinkEye",msgBlinkEye);
        activity.startActivityForResult(intent, 100);
    }


    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        if (resultCode != Activity.RESULT_CANCELED) {

            if (requestCode == 100) {
                if (result != null) {
                    String filePath = data.getStringExtra("filePath");
                    Log.e("filePath.plugin", filePath);
                    result.success(filePath);
                } else {
                    Log.e("RESULT", "NULL");
                }
            }
            return true;
        }
        return false;
    }
}
